summaryrefslogtreecommitdiff
path: root/lib/gnutls_anon_cred.c
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2001-12-05 17:03:52 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2001-12-05 17:03:52 +0000
commitc3bb0dca4238ef75893b00d73a883a8b3f2c7ce3 (patch)
tree4eb0cac0b0da38a8b0812b86481f0f682dcc6d42 /lib/gnutls_anon_cred.c
parent3566f540c2ea57ef3fced95b06f6ba52f4f24ab8 (diff)
downloadgnutls-c3bb0dca4238ef75893b00d73a883a8b3f2c7ce3.tar.gz
Added callback to select the server certificate.
Diffstat (limited to 'lib/gnutls_anon_cred.c')
-rw-r--r--lib/gnutls_anon_cred.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/gnutls_anon_cred.c b/lib/gnutls_anon_cred.c
index ebc42f2436..393fd2ccfa 100644
--- a/lib/gnutls_anon_cred.c
+++ b/lib/gnutls_anon_cred.c
@@ -34,7 +34,7 @@
* this helper function is provided in order to free (deallocate)
* the structure.
**/
-void gnutls_free_anon_server_sc( ANON_SERVER_CREDENTIALS sc) {
+void gnutls_anon_free_server_sc( ANON_SERVER_CREDENTIALS sc) {
gnutls_free(sc);
}
@@ -46,7 +46,7 @@ void gnutls_free_anon_server_sc( ANON_SERVER_CREDENTIALS sc) {
* this helper function is provided in order to allocate
* the structure.
**/
-int gnutls_allocate_anon_server_sc( ANON_SERVER_CREDENTIALS *sc) {
+int gnutls_anon_allocate_server_sc( ANON_SERVER_CREDENTIALS *sc) {
*sc = gnutls_malloc(sizeof( ANON_SERVER_CREDENTIALS));
if (*sc==NULL) return GNUTLS_E_MEMORY_ERROR;
@@ -54,7 +54,7 @@ int gnutls_allocate_anon_server_sc( ANON_SERVER_CREDENTIALS *sc) {
}
/**
* gnutls_set_anon_server_cred - Used to set the number of bits to use in DH, in a ANON_SERVER_CREDENTIALS structure
* @res: is an &ANON_SERVER_CREDENTIALS structure.
* @dh_bits: is the number of bits in DH key exchange
*
@@ -63,7 +63,7 @@ int gnutls_allocate_anon_server_sc( ANON_SERVER_CREDENTIALS *sc) {
*
**/
-int gnutls_set_anon_server_cred( ANON_SERVER_CREDENTIALS res, int dh_bits) {
+int gnutls_anon_set_server_cred( ANON_SERVER_CREDENTIALS res, int dh_bits) {
res->dh_bits = dh_bits;
return 0;
}
@@ -54,7 +54,7 @@ int gnutls_allocate_anon_server_sc( ANON_SERVER_CREDENTIALS *sc) {
}
/**
- * gnutls_set_anon_server_cred - Used to set the number of bits to use in DH, in a ANON_SERVER_CREDENTIALS structure
+ * gnutls_anon_set_server_cred - Used to set the number of bits to use in DH, in a ANON_SERVER_CREDENTIALS structure
* @res: is an &ANON_SERVER_CREDENTIALS structure.
* @dh_bits: is the number of bits in DH key exchange